package com.fasterxml.jackson.databind;

import java.io.*;
import java.util.*;

public class ObjectMapper {
  public ObjectMapper() {
  }

  public void writeValue(File resultFile, Object value) {
  }

  public void writeValue(com.fasterxml.jackson.core.JsonGenerator jgen, Object value) {
  }

  public void writeValue(OutputStream out, Object value) {
  }

  public void writeValue(Writer w, Object value) {
  }

  public byte[] writeValueAsBytes(Object value) {
    return null;
  }

  public String writeValueAsString(Object value) {
    return null;
  }
}
